==> pdf-model-arlington-1.25.28-sources.jar: org/verapdf/model/alayer/AName.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AName extends AObject {
	












	/**
	*/
	public Boolean getcontainsAP();

	/**
	*/
	public String getAPType();

	/**
	*/
	public Boolean getAPHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsAlternatePresentations();

	/**
	*/
	public String getAlternatePresentationsType();

	/**
	*/
	public Boolean getAlternatePresentationsHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsDests();

	/**
	*/
	public String getDestsType();

	/**
	*/
	public Boolean getDestsHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsEmbeddedFiles();

	/**
	*/
	public String getEmbeddedFilesType();

	/**
	*/
	public Boolean getEmbeddedFilesHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsIDS();

	/**
	*/
	public String getIDSType();

	/**
	*/
	public Boolean getIDSHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsJavaScript();

	/**
	*/
	public String getJavaScriptType();

	/**
	*/
	public Boolean getJavaScriptHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsPages();

	/**
	*/
	public String getPagesType();

	/**
	*/
	public Boolean getPagesHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsRenditions();

	/**
	*/
	public String getRenditionsType();

	/**
	*/
	public Boolean getRenditionsHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsTemplates();

	/**
	*/
	public String getTemplatesType();

	/**
	*/
	public Boolean getTemplatesHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsURLS();

	/**
	*/
	public String getURLSType();

	/**
	*/
	public Boolean getURLSHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsXFAResources();

	/**
	*/
	public String getXFAResourcesType();

	/**
	*/
	public Boolean getXFAResourcesHasTypeNameTree();

	/**
	*/
	public Boolean gethasExtensionADBE_Extn3();
}

==> pdf-model-arlington-1.27.9-sources.jar: org/verapdf/model/alayer/AName.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AName extends AObject {
	























	/**
	*/
	public Boolean getcontainsAP();

	/**
	*/
	public String getAPType();

	/**
	*/
	public Boolean getAPHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsAPTreeNode();

	/**
	*/
	public String getAPTreeNodeType();

	/**
	*/
	public Boolean getAPTreeNodeHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsAlternatePresentations();

	/**
	*/
	public String getAlternatePresentationsType();

	/**
	*/
	public Boolean getAlternatePresentationsHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsAlternatePresentationsTreeNode();

	/**
	*/
	public String getAlternatePresentationsTreeNodeType();

	/**
	*/
	public Boolean getAlternatePresentationsTreeNodeHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsDests();

	/**
	*/
	public String getDestsType();

	/**
	*/
	public Boolean getDestsHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsDestsTreeNode();

	/**
	*/
	public String getDestsTreeNodeType();

	/**
	*/
	public Boolean getDestsTreeNodeHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsEmbeddedFiles();

	/**
	*/
	public String getEmbeddedFilesType();

	/**
	*/
	public Boolean getEmbeddedFilesHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsEmbeddedFilesTreeNode();

	/**
	*/
	public String getEmbeddedFilesTreeNodeType();

	/**
	*/
	public Boolean getEmbeddedFilesTreeNodeHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsIDS();

	/**
	*/
	public String getIDSType();

	/**
	*/
	public Boolean getIDSHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsIDSTreeNode();

	/**
	*/
	public String getIDSTreeNodeType();

	/**
	*/
	public Boolean getIDSTreeNodeHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsJavaScript();

	/**
	*/
	public String getJavaScriptType();

	/**
	*/
	public Boolean getJavaScriptHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsJavaScriptTreeNode();

	/**
	*/
	public String getJavaScriptTreeNodeType();

	/**
	*/
	public Boolean getJavaScriptTreeNodeHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsPages();

	/**
	*/
	public String getPagesType();

	/**
	*/
	public Boolean getPagesHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsPagesTreeNode();

	/**
	*/
	public String getPagesTreeNodeType();

	/**
	*/
	public Boolean getPagesTreeNodeHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsRenditions();

	/**
	*/
	public String getRenditionsType();

	/**
	*/
	public Boolean getRenditionsHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsRenditionsTreeNode();

	/**
	*/
	public String getRenditionsTreeNodeType();

	/**
	*/
	public Boolean getRenditionsTreeNodeHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsTemplates();

	/**
	*/
	public String getTemplatesType();

	/**
	*/
	public Boolean getTemplatesHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsTemplatesTreeNode();

	/**
	*/
	public String getTemplatesTreeNodeType();

	/**
	*/
	public Boolean getTemplatesTreeNodeHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsURLS();

	/**
	*/
	public String getURLSType();

	/**
	*/
	public Boolean getURLSHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsURLSTreeNode();

	/**
	*/
	public String getURLSTreeNodeType();

	/**
	*/
	public Boolean getURLSTreeNodeHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsXFAResources();

	/**
	*/
	public String getXFAResourcesType();

	/**
	*/
	public Boolean getXFAResourcesHasTypeNameTree();

	/**
	*/
	public Boolean getcontainsXFAResourcesTreeNode();

	/**
	*/
	public String getXFAResourcesTreeNodeType();

	/**
	*/
	public Boolean getXFAResourcesTreeNodeHasTypeNameTree();
}
